Genesis, Chapter 1 | USCCB

## Genesis

### CHAPTER 1

The Story of Creation. 1In the beginning, when God created the heavens and the earth —a

2and the earth was without form or shape, with darkness over the abyss and a mighty wind sweeping over the waters—b

3Then God said: Let there be light, and there was light.c

4God saw that the light was good. God then separated the light from the darkness.

5God called the light “day,” and the darkness he called “night.” Evening came, and morning followed—the first day.

6Then God said: Let there be a dome in the middle of the waters, to separate one body of water from the other.

7God made the dome, and it separated the water below the dome from the water above the dome. And so it happened.d

8God called the dome “sky.” Evening came, and morning followed—the second day.

9Then God said: Let the water under the sky be gathered into a single basin, so that the dry land may appear. And so it happened: the water under the sky was gathered into its basin, and the dry land appeared.e

10God called the dry land “earth,” and the basin of water he called “sea.” God saw that it was good.

11Then God said: Let the earth bring forth vegetation: every kind of plant that bears seed and every kind of fruit tree on earth that bears fruit with its seed in it. And so it happened:f

12the earth brought forth vegetation: every kind of plant that bears seed and every kind of fruit tree that bears fruit with its seed in it. God saw that it was good.

13Evening came, and morning followed—the third day.

14Then God said: Let there be lights in the dome of the sky, to separate day from night. Let them mark the seasons, the days and the years,g

15and serve as lights in the dome of the sky, to illuminate the earth. And so it happened:

16God made the two great lights, the greater one to govern the day, and the lesser one to govern the night, and the stars.h

17God set them in the dome of the sky, to illuminate the earth,

18to govern the day and the night, and to separate the light from the darkness. God saw that it was good.

19Evening came, and morning followed—the fourth day.

20Then God said: Let the water teem with an abundance of living creatures, and on the earth let birds fly beneath the dome of the sky.i

21God created the great sea monsters and all kinds of crawling living creatures with which the water teems, and all kinds of winged birds. God saw that it was good,

22and God blessed them, saying: Be fertile, multiply, and fill the water of the seas; and let the birds multiply on the earth.j

23Evening came, and morning followed—the fifth day.

24Then God said: Let the earth bring forth every kind of living creature: tame animals, crawling things, and every kind of wild animal. And so it happened:k

25God made every kind of wild animal, every kind of tame animal, and every kind of thing that crawls on the ground. God saw that it was good.

26Then God said: Let us make human beings in our image, after our likeness. Let them have dominion over the fish of the sea, the birds of the air, the tame animals, all the wild animals, and all the creatures that crawl on the earth.l

27God created mankind in his image; in the image of God he created them; male and female he created them.

28God blessed them and God said to them: Be fertile and multiply; fill the earth and subdue it. Have dominion over the fish of the sea, the birds of the air, and all the living things that crawl on the earth.m

29God also said: See, I give you every seed-bearing plant on all the earth and every tree that has seed-bearing fruit on it to be your food;n

30and to all the wild animals, all the birds of the air, and all the living creatures that crawl on the earth, I give all the green plants for food. And so it happened.

31God looked at everything he had made, and found it very good. Evening came, and morning followed—the sixth day.o

a. [1:1] Gn 2:1, 4; 2 Mc 7:28; Ps 8:4; 33:6; 89:12; 90:2; Wis 11:17; Sir 16:24; Jer 10:12; Acts 14:15; Col 1:16–17; Heb 1:2–3; 3:4; 11:3; Rev 4:11.

b. [1:2] Jer 4:23.

c. [1:3] 2 Cor 4:6.

d. [1:7] Prv 8:27–28; 2 Pt 3:5.

e. [1:9] Jb 38:8; Ps 33:7; Jer 5:22.

f. [1:11] Ps 104:14.

g. [1:14] Jb 26:10; Ps 19:2–3; Bar 3:33.

h. [1:16] Dt 4:19; Ps 136:7–9; Wis 13:2–4; Jer 31:35.

i. [1:20] Jb 12:7–10.

j. [1:22] Gn 8:17.

k. [1:24] Sir 16:27–28.

l. [1:26–27] Gn 5:1, 3; 9:6; Ps 8:5–6; Wis 2:23; 10:2; Sir 17:1, 3–4; Mt 19:4; Mk 10:6; Jas 3:7; Eph 4:24; Col 3:10.

m. [1:28] Gn 8:17; 9:1; Ps 8:6–9; 115:16; Wis 9:2.

n. [1:29–30] Gn 9:3; Ps 104:14–15.

o. [1:31] 1 Tm 4:4.